Crate liboscore_cryptobackend

Crate liboscore_cryptobackend 

Backend for liboscore’s crypto API that fans out to AEAD algorithms base on the aead Rust crate.

This takes a mixture of trait- and enum-based approaches; algorithms are handled as trait objects (or constructors derived from them), but the oscore_crypto_aead_encryptstate_t would eventually be an enum in order to be Sized and thus stack-allocatable.

Modules

aead

Enums

CryptoErr
c_void
Void stand-in recognized by the cbindgen library by its name

Functions

oscore_cryptoerr_is_error