#[repr(C)]pub enum CryptoErr {
Ok = 0,
NoSuchAlgorithm = 1,
UnexpectedDataLength = 2,
BufferShorterThanTag = 3,
DecryptError = 4,
AadPreallocationExceeded = 5,
NoIdentifier = 6,
}Variants
Ok = 0
NoSuchAlgorithm = 1
UnexpectedDataLength = 2
Data was put into the AAD, plaintext or buffer whose length was not as originally announced
BufferShorterThanTag = 3
The only possible encryption error
DecryptError = 4
Decryption failed (ie. message corruption / tampering / disagreement on nonce or AAD)
AadPreallocationExceeded = 5
Returned when the AAD is longer than pre-allocated, and neither streaming AAD nor dynamic allocation are not implemented (which is unconditional so far)
NoIdentifier = 6
A kind of identifier was requested of an algorithm that is not specified