#[repr(u8)]pub enum Algorithm {
ChaCha20Poly1305 = 0,
AesCcm16_64_128 = 1,
AesCcm16_128_128 = 2,
A128GCM = 3,
A256GCM = 4,
}Expand description
Expressed as an enum for lack of type variables and/or the unsuitability of the NewAead::new method as a function pointer constructor due to its generic component.
(Possibly one could make a trait that only has an associated type, have it impl’d by the
algorithms as a ZST, have static single objects for each and pass them as &'static dyn, but
that makes them two pointers large. One could probably pick the vtable from trait object
pointers, but that’s deep unsafe territory.)
Variants